@@ -5,13 +5,10 @@ use warnings::register;
 use Carp qw(croak);
 use vars qw($VERSION);
 
-use Locale::Object;
-use base qw( Locale::Object );
-
 use Locale::Object::Country;
 use Locale::Object::DB;
 
-$VERSION = "0.23";
+$VERSION = "0.1";
 
 my $db = Locale::Object::DB->new();
 
@@ -22,6 +19,23 @@ my $existing = {};
 my %continents = map { $_ => undef }
   ('Africa', 'Asia', 'Europe', 'North America', 'Oceania', 'South America');
   
+# Call init() with the parameters we got.
+sub new
+{
+  my $class = shift;
+  my %params = @_;
+  
+  # New Continent object.
+  my $self = bless {}, $class;
+  
+  # Check for pre-existing objects. Return it if there is one.
+  my $continent = $self->exists($params{name});
+  return $continent if $continent;
+  
+  # If not, initialize a new one.
+  $self->init(%params);
+}
+
 # Initialize the object.
 sub init
 {
@@ -108,51 +122,43 @@ sub name
 # Method for retrieving all countries in this continent.
 sub countries
 {
-  my $self = shift;
-   
-  # No name, no countries.
-  return unless $self->{_name};
+    my $self = shift;
+    
+    # Check for countries attribute. Set it if we don't have it.
+    _set_countries($self) if $self->{_name};
     
-  # Check for countries attribute. Set it if we don't have it.
-  _set_countries($self) unless $self->{_countries};
-
-  # Give an array if requested in array context, otherwise a reference.    
-  if (wantarray)
-  {
-    return @{$self->{_countries}};
-  }
-  else
-  {
     return $self->{_countries};
-  }
 }
 
-# Private method to set an attribute with an array of objects for all countries in this continent.
+# Private method to set an attribute with a hash of objects for all countries in this continent.
 sub _set_countries
 {
     my $self = shift;
 
-    my (%country_codes, @countries);
+    # Do nothing if the list already exists.
+    return if $self->{_countries};
+
+    my (%country_codes, %countries);
     
-    # If it doesn't, find all countries in this continent.
-    my $result = $db->lookup(
-                                      table => 'continent', 
-                                      result_column => 'country_code', 
-                                      search_column => 'name', 
-                                      value => $self->{'_name'}
-                                     );
-
-    # Create new country objects and put them into an array.
-    foreach my $place (@{$result})
+    # If it doesn't, find all countries in this continent and put them in a hash.
+    foreach my $result ( $db->lookup_all(
+                                        table => "continent", 
+                                        result_column => "country_code", 
+                                        search_column => "name", 
+                                        value => $self->{'_name'} ) )
     {
-      my $where = $place->{'country_code'};
-
-      my $obj = Locale::Object::Country->new( code_alpha2 => $where );
-      push @countries, $obj; 
+      $country_codes{$result} = 1;
     }
-        
-    # Set a reference to that array as an attribute.
-    $self->{'_countries'} = \@countries;
+    
+    # Create new country objects and put them into a hash.
+    foreach my $where (keys %country_codes)
+    {
+      my $obj = Locale::Object::Country->new( code_alpha2 => $where );
+      $countries{$where} = $obj;
+    }
+    
+    # Set a reference to that hash as an attribute.
+    $self->{'_countries'} = \%countries;
 }
 
 1;
@@ -165,7 +171,7 @@ Locale::Object::Continent - continent information objects
 
 =head1 VERSION
 
-0.23
+0.1
 
 =head1 DESCRIPTION
 
@@ -173,10 +179,11 @@ C<Locale::Object::Continent> allows you to create objects representing continent
 
 =head1 SYNOPSIS
 
-    my $asia      = Locale::Object::Continent->new( name => 'Asia' );
+    my $asia                     = Locale::Object::Continent->new( name => 'Asia' );
 
-    my $name      = $asia->name;
-    my @countries = $asia->countries;
+    my $name                     = $asia->name;
+    my %countries                = %{$asia->countries};
+    my $currency_of_afghanistan  = $countries{'af'}->currency->name;
 
 =head1 METHODS
 
@@ -188,29 +195,20 @@ The C<new> method creates an object. It takes a single-item hash as an argument
 
 The objects created are singletons; if you try and create a continent object when one matching your specification already exists, C<new()> will return the original one.
 
-=head2 C<name()>
+=head2 C<name>
 
     my $name = $asia->name;
     
 Retrieves the value of the continent object's name.
 
-=head2 C<countries()>
+=head2 C<countries>
 
-    my @countries = $asia->countries;
+Returns a hash of L<Locale::Object::Country> objects with their ISO 3166 alpha2 codes as keys (see L<Locale::Object::DB::Schemata> for more details on those). These have their own attribute methods, so you can do things like this:
 
-Returns an array of L<Locale::Object::Country> objects with their ISO 3166 alpha2 codes as keys (see L<Locale::Object::DB::Schemata> for more details on those) in array context, or a reference in scalar context. The objects have their own attribute methods, so you can do things like this:
+    my %countries                = %{$asia->countries};
+    my $currency_of_afghanistan  = $countries{'af'}->currency->name;
 
-    foreach my $place (@countries)
-    {
-      print $place->name, "\n";
-    }
-    
-Which will list you all the currencies used in that continent. See the documentation for L<Locale::Object::Country> for a listing of country attributes. Note that you can chain methods as well.
-
-    foreach my $place (@countries)
-    {
-      print $place->currency->name, "\n";
-    }
+See the documentation for L<Locale::Object::Country> for a listing of country attributes.
 
 =head1 AUTHOR
 
