@@ -2,16 +2,13 @@ package Locale::Object::Currency;
 
 use strict;
 use warnings::register;
-use Carp;
+use Carp qw(croak);
 use vars qw($VERSION);
 
-use Locale::Object;
-use base qw( Locale::Object );
-
 use Locale::Object::Country;
 use Locale::Object::DB;
 
-$VERSION = "0.23";
+$VERSION = "0.1";
 
 my $db = Locale::Object::DB->new();
 
@@ -20,6 +17,17 @@ my $existing = {};
 
 my $class;
 
+sub new
+{
+  my $class = shift;
+  my %params = @_;
+
+  my $self = bless {}, $class;
+  
+  # Initialize the new object or return an existing one.
+  $self->init(%params);
+}
+
 # Initialize the object.
 sub init
 {
@@ -43,54 +51,26 @@ sub init
   # Get the value given for the parameter.
   my $value = $params{$parameter};
 
-  # Make sure input matches style of values in the db.
-  if ($parameter eq 'country_code')
-  {
-    $value = lc($value);
-  }
-  elsif ($parameter eq 'code')
-  {
-    $value = uc($value);
-  }
-  
   # Look in the database for a match.
-  my $result = $db->lookup(
-                           table         => 'currency',
-                           result_column => '*',
-                           search_column => $parameter,
-                           value         => $value
-                          );
+  my @attributes = $db->lookup('currency', $parameter, $value);
 
-  croak "Error: Unknown $parameter given for initialization: $value" unless $result;
+  croak "Error: Unknown $parameter given for initialization: $value" unless @attributes;
+  
+  # The third attribute we get is the currency code.
+  my $code = $attributes[2]; 
+  
+  # Check for pre-existing objects. Return it if there is one.
+  my $currency = $self->exists($code);
+  return $currency if $currency;
 
-  if (defined @{$result}[0])
-  {
-    # Set values from the results of our query.
-    my $name           = @{$result}[0]->{'name'}; 
-    my $code           = @{$result}[0]->{'code'}; 
-    my $code_numeric   = @{$result}[0]->{'code_numeric'}; 
-    my $symbol         = @{$result}[0]->{'symbol'}; 
-    my $subunit        = @{$result}[0]->{'subunit'}; 
-    my $subunit_amount = @{$result}[0]->{'subunit_amount'}; 
-    
-    # Check for pre-existing objects. Return it if there is one.
-    my $currency = $self->exists($code);
-    return $currency if $currency;
+  # If not, make a new object.
+  _make_currency($self, @attributes);
   
-    # If not, make a new object.
-    _make_currency($self, $name, $code, $code_numeric, $symbol, $subunit, $subunit_amount);
-    
-    # Register the new object.
-    $self->register();
-  
-    # Return the object.
-    $self;
-  }
-  else
-  {
-    carp "Warning: No result found in currency table for '$value' in $parameter.";
-    return;
-  }
+  # Register the new object.
+  $self->register();
+
+  # Return the object.
+  $self;
 }
 
 # Check if objects exist.
@@ -122,19 +102,20 @@ sub _make_currency
   my @attributes = @_;
 
   # The third attribute we get is the currency code.
-  my $currency_code = $attributes[0];
+  my $currency_code = $attributes[2];
   
   # The attributes we want to set.
-  my @attr_names = qw(name code code_numeric symbol subunit subunit_amount);
+  my @attr_names = qw(_name _code _code_numeric _symbol _subunit _subunit_amount);
   
   # Initialize a loop counter.
-  my $counter = 0;
+  my $counter = 1;
   
   foreach my $current_attribute (@attr_names)
   {
     # Set the attributes of the entry for this currency code in the singleton hash.
-    $self->$current_attribute( $attributes[$counter] );
-   
+    
+    $self->{$current_attribute} = $attributes[$counter];
+    
     $counter++; 
   }
 
@@ -145,14 +126,9 @@ sub countries
 {
     my $self = shift;
     
-    # No name, no countries.
-    return unless $self->{_name};
-    
     # Check for countries attribute. Set it if we don't have it.
-    _set_countries($self) unless $self->{_countries};
-
-    # Give an array if requested in array context, otherwise a reference.    
-    return @{$self->{_countries}} if wantarray;
+    _set_countries($self) if $self->{_name};
+    
     return $self->{_countries};
 }
 
@@ -162,107 +138,69 @@ sub _set_countries
     my $self = shift;
 
     my $code = $self->{_code};
-        
+    
+    # Do nothing if the list already exists.
+    return if $existing->{$code}->{'_countries'};
+    
     # If it doesn't, find all countries using this currency and put them in a hash.
-    my (%country_codes, @countries);
+    my (%country_codes, %countries);
     
-    my $result = $db->lookup(
-                                      table => "currency", 
-                                      result_column => "country_code", 
-                                      search_column => "code", 
-                                      value => $existing->{$code}->{'_code'}
-                                     );
-    
-    # Create new country objects and put them into an array.
-    foreach my $place (@{$result})
+    foreach my $result ( $db->lookup_all(
+                                        table => "currency", 
+                                        result_column => "country_code", 
+                                        search_column => "code", 
+                                        value => $existing->{$code}->{'_code'} ) )
     {
-      my $where = $place->{'country_code'};
-      
-      my $obj = Locale::Object::Country->new( code_alpha2 => $where );
-      push @countries, $obj;
+      $country_codes{$result} = 1;
     }
     
-    # Set a reference to that array as an attribute.
-    $self->{'_countries'} = \@countries;       
+    # Create new country objects and put them into a hash.
+    foreach my $where (keys %country_codes)
+    {
+      my $obj = Locale::Object::Country->new( code_alpha2 => $where );
+      $countries{$where} = $obj;
+    }
+    
+    # Set a reference to that hash as an attribute.
+    $existing->{$code}->{'_countries'} = \%countries;       
 }
 
-# Get/set attributes.
+# Small methods that return object attributes.
+# Will refactor these into an AUTOLOAD later.
 
 sub code
 {
   my $self = shift;  
-
-  if (@_)
-  {
-    $self->{_code} = shift;
-    return $self;
-  }
-
   $self->{_code};
 }
 
 sub name
 {
-  my $self = shift;
-
-  if (@_)
-  {
-    $self->{_name} = shift;
-    return $self;
-  }
-  
+  my $self = shift;  
   $self->{_name};
 }
 
 sub code_numeric
 {
-  my $self = shift;
-
-  if (@_)
-  {
-    $self->{_code_numeric} = shift;
-    return $self;
-  }
-
+  my $self = shift;  
   $self->{_code_numeric};
 }  
 
 sub symbol
 {
-  my $self = shift;
-
-  if (@_)
-  {
-    $self->{_symbol} = shift;
-    return $self;
-  }
-  
+  my $self = shift;  
   $self->{_symbol};
 }
 
 sub subunit
 {
   my $self = shift;  
-
-  if (@_)
-  {
-    $self->{_subunit} = shift;
-    return $self;
-  }
-
   $self->{_subunit};
 }
 
 sub subunit_amount
 {
   my $self = shift;  
-
-  if (@_)
-  {
-    $self->{_subunit_amount} = shift;
-    return $self;
-  }
-
   $self->{_subunit_amount};
 }
 
@@ -276,7 +214,7 @@ Locale::Object::Currency - currency information objects
 
 =head1 VERSION
 
-0.23
+0.1
 
 =head1 DESCRIPTION
 
@@ -295,7 +233,7 @@ C<Locale::Object::Country> allows you to create objects containing information a
     my $subunit        = $usd->subunit;
     my $subunit_amount = $usd->subunit_amount;
     
-    my @countries      = $usd->countries;
+    my %countries = %{$usd->countries};
 
 =head1 METHODS
 
@@ -303,33 +241,38 @@ C<Locale::Object::Country> allows you to create objects containing information a
 
     my $usd = Locale::Object::Currency->new( country_code => 'us' );
 
-The C<new> method creates an object. It takes a single-item hash as an argument - valid options to pass are ISO 3166 values - 'code' and 'code_numeric'; also 'country_code', which is an alpha2 country code (see L<Locale::Object::DB::Schemata> for details on these). If you give a country code, a currency object will be created representing the currency of the country you specified.
+The C<new> method creates an object. It takes a single-item hash as an argument - valid options to pass are ISO 3166 values - 'code', 'code_numeric' and 'name', and also 'country_code', which is an alpha2 country code (see L<Locale::Object::DB::Schemata> for details on these). If you give a country code, a currency object will be created representing the currency of the country you specified.
 
 The objects created are singletons; if you try and create a currency object when one matching your specification already exists, C<new()> will return the original one.
 
-=head2 C<name(), code(), code_numeric(), symbol(), subunit(), subunit_amount()>
+=head2 C<name, code, code_numeric, symbol, subunit, subunit_amount>
 
     my $name = $country->name;
     
 These methods retrieve the values of the attributes in the object whose name they share.
 
-=head2 C<countries()>
+=head2 C<countries>
 
-    my @countries = $usd->countries;
+    my %countries = %{$usd->countries};
 
-Returns an array (in array context, otherwise a reference) of L<Locale::Object::Country> objects with their ISO 3166 alpha2 codes as keys (see L<Locale::Object::DB::Schemata> for more details on those) for all countries using this currency in array context, or a reference in scalar context. The objects have their own attribute methods, so you can do things like this for example:
+Returns a hash of L<Locale::Object::Country> objects with their ISO 3166 alpha2 codes as keys (see L<Locale::Object::DB::Schemata> for more details on those) for all countries using this currency. These have their own attribute methods, so you can do things like this for example:
 
-    foreach my $place (@countries)
+    foreach my $country (sort keys %countries)
     {
-      print $place->name, "\n";
+      print "- ", $countries{$country}->name, "\n";
     }
     
-Which will list you all the countries that use in that currency. See the documentation for L<Locale::Object::Country> for a listing of country attributes. Note that you can chain methods as well.
-
-    foreach my $place (@countries)
-    {
-      print $place->continent->name, "\n";
-    }
+    # prints:
+    # - American Samoa
+    # - Guam
+    # - Palau
+    # - Puerto Rico 
+    # - Turks and Caicos Islands
+    # - United States 
+    # - Virgin Islands, British
+    # - Virgin Islands, U.S.
+    
+See the documentation for L<Locale::Object::Country> for a listing of country attributes.
 
 =head1 KNOWN BUGS
 
