@@ -1,11 +1,5 @@
 package Locale::Object::DB::Schemata
 
-use strict;
-use warnings::register;
-use vars qw($VERSION);
-
-$VERSION = "0.31";
-
 # DO NOT LEAVE IT IS NOT REAL
 
 sub new
@@ -23,7 +17,7 @@ Locale::Object::DB::Schemata - schema documentation for the Locale::Object datab
 
 =head1 VERSION
 
-0.31
+0.1
 
 =head1 DESCRIPTION
 
@@ -40,19 +34,17 @@ The database of locale information used by the Locale::Object modules uses L<DBD
         code_alpha3           char(3),
         code_numeric          smallint,
         name                  char(100),
-        dialing_code          smallint,
-        utc_offset_main       char(5),
-        utc_offsets_all       char(50),
+        name_native           char(100),
+        primary_language      char(3),
+        main_timezone         tinyint,
+        uses_daylight_savings char(3),
         PRIMARY KEY           (code_alpha2)
     );
 
 =over 4
 
 * C<code_alpha2> , C<code_alpha3>, C<code_numeric> and C<name> are data from ISO 3166 - see L<http://ftp.ics.uci.edu/pub/ietf/http/related/iso3166.txt>.
-
-* C<dialing_code> is an International Direct Dialing code - see L<http://kropla.com/dialcode.htm>.
-
-* C<utc_offset_main> is the time offset of the time zone of the country's capital from UTC, expressed decimally in hours. C<utc_offsets_all> is a comma-separated list of offsets for all time zones that the country falls across, listed from west to east. If there is only one value this will match C<utc_offset_main>.
+* C<name_native>, C<primary_language>, C<main_timezone> and C<uses_daylight_savings> are currently empty, but will be utilized in a forthcoming release of these modules.
 
 =back
 
@@ -69,16 +61,12 @@ The database of locale information used by the Locale::Object modules uses L<DBD
         PRIMARY KEY  (country_code)
     );
 
-=over 4
-
 * C<country_code> contains ISO 3166 two-letter country codes, as in the previous table.
 
 * C<name> and C<code> contain ISO 4217 three-letter codes and names for world currencies - see L<http://fx.sauder.ubc.ca/iso4217.html>.
 
 * C<symbol>, C<subunit> and C<subunit_amount> contain currency symbols, subunits (such as cents) and the amounts of subunits that comprise a single currency unit (such as 100 [cents in a dollar]). This data was sourced from L<http://fx.sauder.ubc.ca/currency_table.html>.
 
-=back
-
 =head2 the 'continent' table
     
     CREATE TABLE continent (
@@ -87,12 +75,8 @@ The database of locale information used by the Locale::Object modules uses L<DBD
         PRIMARY KEY  (country_code)
     );
 
-=over 4
-
 * C<country_code> contains ISO 3166 two-letter codes again, and C<name> contains associated continent names (Africa, Asia, Europe, North America, Oceania and South America). Sourced from L<http://www.worldatlas.com/cntycont.htm>.
 
-=back
-
 =head2 the 'language' table
     
     CREATE TABLE language (
@@ -112,39 +96,7 @@ The database of locale information used by the Locale::Object modules uses L<DBD
 
 =back
 
-=head2 the 'language_mappings' table
-
-    CREATE TABLE language_mappings (
-        id           char(4),
-        country      char(2),
-        language     char(3),
-        official     boolean,
-        PRIMARY KEY (id)
-    );
-    
-An example section of this table:
-
-    ID   COUNTRY  LANGUAGE  OFFICIAL
-    at_0   at       ger      true
-    at_1   at       slv      false
-    at_2   at       hrv      false
-    at_3   at       hun      false
-
-What this tells us is that in Austria, four languages are spoken: German, Slovenian, Croatian (Hrvatska) and Hungarian, and that only German is an official language of Austria. The mappings are ranked in order of prevalence of language, official languages first, followed by non-official. Please note that this is approximate at best. 
-
-My original source for the language-country mappings was L<http://www.infoplease.com/ipa/A0855611.html>. However, there is no clear origin for this list, which occurs in several places on the Web, and it required some serious rationalization before data was able to be usefully extracted for it.
- 
-In addition to the preceding, the following sources were invaluable:
-
-=over 4
-
-* L<http://www.nationmaster.com/>
-
-* L<http://www.ethnologue.com/>
-
-* L<http://www.wikipedia.org/>
-
-=back
+In addition to the quoted sources, I also got some information from the fabulous L<http://www.nationmaster.com/>.
 
 =head1 AUTHOR
 
